@@ -1,15 +1,20 @@
-import pandas as pd
-import yaml
 import hashlib
 import os
 
+import pandas as pd
+import yaml
+from dotenv import load_dotenv
 
-def add_technical_col(data: pd.DataFrame, t_name: str, date: str = None, entity_name: str = None,buildHashKey:bool=False):
-    if os.path.isfile(r'/Configs/ENB/{entity}.yaml'.format(entity=entity_name)):
-        conf = r'/Configs/ENB/{entity}.yaml'.format(entity=entity_name)
-    else:
-        conf = r'../Configs/ENB/{entity}.yaml'.format(entity=entity_name)
 
+
+
+def add_technical_col(data: pd.DataFrame, t_name: str, date: str = None, entity_name: str = None,
+                      buildHashKey: bool = False):
+    load_dotenv()
+    db_conf = os.getenv('DB_CONFIG')
+    kp_path = os.getenv('KEYPASS')
+    conf_r = os.getenv('ENTITY_CONFIGS')
+    conf = os.path.join(conf_r, '{entity}.yaml'.format(entity=entity_name))
     with open(conf) as file:
         documents = yaml.full_load(file)
 
@@ -37,6 +42,6 @@ def add_technical_col(data: pd.DataFrame, t_name: str, date: str = None, entity_
 
         data['help'] = data[bks].astype(str).agg('|'.join, axis=1)
         data[hk_name] = data['help'].apply(
-        lambda x: hashlib.md5(x.encode()).hexdigest().upper())
+            lambda x: hashlib.md5(x.encode()).hexdigest().upper())
 
     return data
