@@ -61,7 +61,7 @@ class LoadtoDB():
             self.hk = self.documents[t_name]['hash_key']
             self.fields = self.documents[t_name]['fields']
         else:
-            with open(os.path.join(conf_r + self.entityName + '.yaml')) as file:
+            with open(os.path.join(conf_r , self.entityName + '.yaml')) as file:
                 self.documents = yaml.full_load(file)
             self.hk = self.documents[entityName]['tables'][self.t_name]['hash_key']
             self.fields = self.documents[entityName]['tables'][self.t_name]['fields']
